@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 sub new {
 	my ( $class, $container ) = @_;
@@ -48,10 +48,6 @@ sub remove {
 		$self->_add_reversed_list($objects_for_cleanup);
 		$self->_cleanup();
 	}
-	else {
-		die "no configuration found\n";
-		return;
-	}
 }
 
 sub result { return $_[0]->{REMOVE} }
@@ -107,6 +103,7 @@ sub _collect_garbage {
 	my $index = Object::KVC::Index->new( $self->fw );
 	$index->make_index( 'ENTRY', 'ID' );
 
+	my $NAME  = Object::KVC::String->new('NAME');
 	my $GROUP  = Object::KVC::String->new('GROUP');
 	my $RULE   = Object::KVC::String->new('RULE');
 	my $OBJECT = Object::KVC::String->new('OBJECT');
@@ -193,12 +190,16 @@ sub _collect_garbage {
 			$remove->add($object);
 
 		}
+		elsif ( $object->get('ENTRY')->equals($NAME) ) {
+			next;
+		}
 		elsif ( $object->get('ENTRY')->equals($INTERFACE) ) {
 			next;
 		}
 		elsif ( $object->get('ENTRY')->equals($ROUTE) ) {
 			next;
 		}
+
 		else {
 			confess "\nI don't know what this is:\n", $object->dump();
 		}
